# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.monitor_state_group import MonitorStateGroup

    globals()["MonitorStateGroup"] = MonitorStateGroup


class MonitorState(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "groups": ({str: (MonitorStateGroup,)},),
        }

    attribute_map = {
        "groups": "groups",
    }

    def __init__(self, *args, **kwargs):
        """
        Wrapper object with the different monitor states.

        :param groups: Dictionary where the keys are groups (comma separated lists of tags) and the values are
            the list of groups your monitor is broken down on.
        :type groups: {str: (MonitorStateGroup,)}, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(MonitorState, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
